# Please keep this package in sync with FC

# -*- rpm-spec -*-

%define with_mingw 0
%if 0%{?mageia}
    %define with_mingw 0%{!?_without_mingw:1}
%endif

Group: System/Base
Summary: Tools for managing the osinfo database
Name: osinfo-db-tools
Version: 1.11.0
Release: %mkrel 2
License: GPLv2+
URL: https://libosinfo.org
Source: https://releases.pagure.org/libosinfo/%{name}-%{version}.tar.xz

# Fix build for libxml2-2.12
Patch:  https://gitlab.com/libosinfo/osinfo-db-tools/-/merge_requests/80.patch

BuildRequires: meson
BuildRequires: gcc
BuildRequires: gettext-devel
BuildRequires: git
BuildRequires: pkgconfig(glib-2.0)
BuildRequires: pkgconfig(libxml-2.0) >= 2.6.0
BuildRequires: pkgconfig(libxslt) >= 1.0.0
BuildRequires: pkgconfig(libarchive)
BuildRequires: pkgconfig(libsoup-3.0)
BuildRequires: pkgconfig(json-glib-1.0)
BuildRequires: perl

#Required for testing purposes
BuildRequires: python3
BuildRequires: python3-pytest
BuildRequires: python3-requests

%if %{with_mingw}
BuildRequires: mingw32-filesystem
BuildRequires: mingw32-gcc
BuildRequires: mingw32-binutils
BuildRequires: mingw32-glib2
BuildRequires: mingw32-json-glib
BuildRequires: mingw32-libxml2
BuildRequires: mingw32-libxslt
BuildRequires: mingw32-libarchive
BuildRequires: mingw32-libsoup

BuildRequires: mingw64-filesystem
BuildRequires: mingw64-gcc
BuildRequires: mingw64-binutils
BuildRequires: mingw64-glib2
BuildRequires: mingw64-json-glib
BuildRequires: mingw64-libxml2
BuildRequires: mingw64-libxslt
BuildRequires: mingw64-libarchive
BuildRequires: mingw64-libsoup
%endif

%description
This package provides tools for managing the osinfo database of
information about operating systems for use with virtualization

%if %{with_mingw}
%package -n mingw32-osinfo-db-tools
Summary: %{summary}
BuildArch: noarch
Requires: pkgconfig

%description -n mingw32-osinfo-db-tools
This package provides tools for managing the osinfo database of
information about operating systems for use with virtualization

%package -n mingw64-osinfo-db-tools
Summary: %{summary}
BuildArch: noarch
Requires: pkgconfig

%description -n mingw64-osinfo-db-tools
This package provides tools for managing the osinfo database of
information about operating systems for use with virtualization

%{?mingw_debug_package}
%endif

%prep
%autosetup -S git

%build
%meson
%meson_build

%if %{with_mingw}
%mingw_meson
%mingw_ninja
%endif

%check
%meson_test

%install
%meson_install

%find_lang %{name}

%if %{with_mingw}
%mingw_ninja_install

# Manpages don't need to be bundled
rm -rf $RPM_BUILD_ROOT%{mingw32_datadir}/man
rm -rf $RPM_BUILD_ROOT%{mingw64_datadir}/man

%mingw_debug_install_post

%mingw_find_lang osinfo-db-tools
%endif

%files -f %{name}.lang
%doc NEWS README
%license COPYING
%{_bindir}/osinfo-db-export
%{_bindir}/osinfo-db-import
%{_bindir}/osinfo-db-path
%{_bindir}/osinfo-db-validate
%{_mandir}/man1/osinfo-db-export.1*
%{_mandir}/man1/osinfo-db-import.1*
%{_mandir}/man1/osinfo-db-path.1*
%{_mandir}/man1/osinfo-db-validate.1*

%if %{with_mingw}
%files -n mingw32-osinfo-db-tools -f mingw32-osinfo-db-tools.lang
%doc NEWS README
%license COPYING
%{mingw32_bindir}/osinfo-db-export.exe
%{mingw32_bindir}/osinfo-db-import.exe
%{mingw32_bindir}/osinfo-db-path.exe
%{mingw32_bindir}/osinfo-db-validate.exe

%files -n mingw64-osinfo-db-tools -f mingw64-osinfo-db-tools.lang
%doc NEWS README
%license COPYING
%{mingw64_bindir}/osinfo-db-export.exe
%{mingw64_bindir}/osinfo-db-import.exe
%{mingw64_bindir}/osinfo-db-path.exe
%{mingw64_bindir}/osinfo-db-validate.exe
%endif



%changelog
* Sun Mar 16 2025 wally <wally> 1.11.0-2.mga10
+ Revision: 2164978
- rebuild for libxml2 2.13.6

* Mon Sep 30 2024 daviddavid <daviddavid> 1.11.0-1.mga10
+ Revision: 2102083
- new version: 1.11.0

* Thu Oct 19 2023 daviddavid <daviddavid> 1.10.0-4.mga10
+ Revision: 1998922
- fix libsoup3 build dependency

* Tue Nov 08 2022 tv <tv> 1.10.0-3.mga9
+ Revision: 1904656
- Pull in mingw sub-packages
- Switch to soup3
- Drop mga6 area conflicts

* Tue Mar 29 2022 umeabot <umeabot> 1.10.0-2.mga9
+ Revision: 1832167
- Mageia 9 Mass Rebuild

* Wed Feb 16 2022 tv <tv> 1.10.0-1.mga9
+ Revision: 1778262
- Update to 1.10.0 release

* Sun Feb 28 2021 tv <tv> 1.9.0-1.mga9
+ Revision: 1693323
- 1.9.0

* Sat May 30 2020 tv <tv> 1.8.0-1.mga8
+ Revision: 1589117
- Update to 1.8.0 release
+ danf <danf>
- Switch URLs from http: to https:

* Tue Feb 18 2020 umeabot <umeabot> 1.7.0-2.mga8
+ Revision: 1539074
- Mageia 8 Mass Rebuild

* Fri Nov 29 2019 tv <tv> 1.7.0-1.mga8
+ Revision: 1463775
- Update to 1.7.0 release

* Tue Aug 06 2019 tv <tv> 1.6.0-1.mga8
+ Revision: 1427688
- new release

* Mon Jul 01 2019 tv <tv> 1.5.0-1.mga8
+ Revision: 1416633
- new release
- Fix coverity issues

* Mon Mar 04 2019 tv <tv> 1.4.0-1.mga7
+ Revision: 1371457
- fix URL
- new release

* Sun Feb 03 2019 tv <tv> 1.3.0-1.mga7
+ Revision: 1362862
- new release

* Sun Sep 23 2018 umeabot <umeabot> 1.2.0-2.mga7
+ Revision: 1300064
- Mageia 7 Mass Rebuild

* Wed Jun 20 2018 tv <tv> 1.2.0-1.mga7
+ Revision: 1238320
- fix tarball (SOURCES)
- new release

* Fri Jul 21 2017 tv <tv> 1.1.0-2.mga7
+ Revision: 1125792
- add conflicts with libosinfo-common

* Fri Jul 21 2017 tv <tv> 1.1.0-1.mga7
+ Revision: 1125791
- imported package osinfo-db-tools


* Thu Jul 20 2017 Thierry Vignaud <tv@mageia.org> 1.1.0-1.mga7
- import from FC

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Oct 26 2016 Daniel P. Berrange <berrange@redhat.com> - 1.1.0-1
- Update to 1.1.0 release

* Fri Jul 29 2016 Daniel P. Berrange <berrange@redhat.com> - 1.0.0-1
- Initial package after split from libosinfo (rhbz #1361594)
